@@ -10,7 +10,7 @@
 #' @param vignettes also check all `rmd` and `rnw` files in the pkg `vignettes` folder
 #' @param use_wordlist ignore words in the package [WORDLIST][spelling::get_wordlist] file
 spell_check <- function(pkg = ".", vignettes = TRUE, use_wordlist = TRUE) {
-  check_suggested("spelling")
+  rlang::check_installed("spelling")
   pkg <- as.package(pkg)
   spelling::spell_check_package(pkg = pkg, vignettes = vignettes, use_wordlist = use_wordlist)
 }
